@@ -128,6 +128,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -152,14 +154,14 @@ class ApiGatewayToKinesisStreams(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
-        put_record_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
+        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        put_record_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
         put_record_request_template: typing.Optional[builtins.str] = None,
-        put_records_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
+        put_records_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
         put_records_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -179,6 +181,10 @@ class ApiGatewayToKinesisStreams(
         :since: 1.62.0
         :summary: Constructs a new instance of the ApiGatewayToKinesisStreams class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToKinesisStreams.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToKinesisStreamsProps(
             api_gateway_props=api_gateway_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
@@ -245,14 +251,14 @@ class ApiGatewayToKinesisStreamsProps:
     def __init__(
         self,
         *,
-        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
+        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
-        put_record_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
+        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        put_record_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
         put_record_request_template: typing.Optional[builtins.str] = None,
-        put_records_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
+        put_records_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
         put_records_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -278,6 +284,17 @@ class ApiGatewayToKinesisStreamsProps:
             put_record_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_record_request_model)
         if isinstance(put_records_request_model, dict):
             put_records_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_records_request_model)
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToKinesisStreamsProps.__init__)
+            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
+            check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
+            check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument put_record_request_model", value=put_record_request_model, expected_type=type_hints["put_record_request_model"])
+            check_type(argname="argument put_record_request_template", value=put_record_request_template, expected_type=type_hints["put_record_request_template"])
+            check_type(argname="argument put_records_request_model", value=put_records_request_model, expected_type=type_hints["put_records_request_model"])
+            check_type(argname="argument put_records_request_template", value=put_records_request_template, expected_type=type_hints["put_records_request_template"])
         self._values: typing.Dict[str, typing.Any] = {}
         if api_gateway_props is not None:
             self._values["api_gateway_props"] = api_gateway_props
